@@ -8,84 +8,15 @@
 
 import json
 import pathlib
+import warnings
 
 import jsonschema
 
-from .exceptions import CluError
+from .exceptions import CluError, CluWarning
 from .tools import CallbackMixIn, CaseInsensitiveDict
 
 
-__all__ = ['Reply', 'Property', 'BaseModel', 'Model', 'ModelSet']
-
-
-class Reply(object):
-    """A container for a `~aio_pika.IncomingMessage` that expands and decodes it.
-
-    Parameters
-    ----------
-    message : aio_pika.IncomingMessage
-        The message that contains the reply.
-    ack : bool
-        Whether to acknowledge the message.
-
-    Attributes
-    ----------
-    is_valid : bool
-        Whether the message is valid and correctly parsed.
-    body : dict
-        The body of the message, as a JSON dictionary.
-    info : dict
-        The info dictionary.
-    headers : dict
-        The headers of the message, decoded if they are bytes.
-    message_code : str
-        The message code.
-    sender : str
-        The name of the actor that sends the reply.
-    command_id
-        The command ID.
-
-    """
-
-    def __init__(self, message, ack=True):
-
-        self.message = message
-
-        self.is_valid = True
-
-        self.body = None
-
-        # Acknowledges receipt of message
-        if ack:
-            message.ack()
-
-        self.info = message.info()
-
-        self.headers = self.info['headers']
-        for key in self.headers:
-            if isinstance(self.headers[key], bytes):
-                self.headers[key] = self.headers[key].decode()
-
-        self.message_code = self.headers.get('message_code', None)
-        if self.message_code is None:
-            self.log.warning(f'received message without message_code: {message}')
-
-        self.sender = self.headers.get('sender', None)
-        if self.sender is None:
-            self.log.warning(f'received message without sender: {message}')
-
-        self.command_id = message.correlation_id
-
-        command_id_header = self.headers.get('command_id', None)
-        if command_id_header and command_id_header != self.command_id:
-            self.log.error(f'mismatch between message '
-                           f'correlation_id={self.command_id} '
-                           f'and header command_id={command_id_header} '
-                           f'in message {message}')
-            self.is_valid = False
-            return
-
-        self.body = json.loads(self.message.body.decode())
+__all__ = ['Property', 'BaseModel', 'Model', 'ModelSet']
 
 
 class Property(CallbackMixIn):
@@ -152,8 +83,6 @@ class BaseModel(CaseInsensitiveDict, CallbackMixIn):
         A function or coroutine to call when the datamodel changes. The
         function is called with the instance of `.BaseModel` and the key that
         changed.
-    log : ~logging.Logger
-        Where to log messages.
 
     """
 
@@ -161,8 +90,6 @@ class BaseModel(CaseInsensitiveDict, CallbackMixIn):
 
         self.name = name
 
-        self.log = log
-
         CaseInsensitiveDict.__init__(self, {})
         CallbackMixIn.__init__(self, [callback] if callback else [])
 
@@ -223,7 +150,8 @@ class Model(BaseModel):
 
         self.validator = self.VALIDATOR(self.schema)
 
-        if self.schema['type'] != 'object' or 'properties' not in self.schema:
+        if ('type' not in self.schema or self.schema['type'] != 'object' or
+                'properties' not in self.schema):
             raise ValueError('Schema must be of type object.')
 
         # All models must have these keys.
@@ -268,10 +196,6 @@ class Model(BaseModel):
         try:
             self.validator.validate(instance)
         except jsonschema.exceptions.ValidationError as err:
-            if self.log:
-                self.log.error(f'Model {self.name} cannot be updated. '
-                               f'Failed validating instance {instance}: '
-                               f'{err}.')
             return False, err
 
         for key, value in instance.items():
@@ -322,8 +246,6 @@ class ModelSet(dict):
         self.client = client
         self.actors = actors
 
-        self.log = kwargs.get('log', None)
-
         self.__raise_exception = raise_exception
         self.__get_schema = get_schema_command
         self.__kwargs = kwargs
@@ -356,7 +278,7 @@ class ModelSet(dict):
             except Exception as err:
 
                 if not self.__raise_exception:
-                    if self.log:
-                        self.log.warning(f'Cannot load model {actor!r}. {err}')
+                    warnings.warn(f'Cannot load model {actor!r}. {err}',
+                                  CluWarning)
                     continue
                 raise
